==> react-atom-progress-bar-1.8.0.tgz: package/lib/LineProgressBar/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomLineProgressBar';
var CLASS_INDICATOR = 'sui-AtomLineProgressBar-indicator';
var CLASS_CONTAINER_BAR = 'sui-AtomLineProgressBar-container';
var CLASS_BAR = 'sui-AtomLineProgressBar-bar';
var CLASS_BAR_ANIMATED = 'sui-AtomLineProgressBar-bar--animated';

var Indicator = function Indicator(props) {
  var indicatorBottom = props.indicatorBottom,
      percentage = props.percentage,
      indicatorTotal = props.indicatorTotal; // eslint-disable-line react/prop-types

  return React.createElement("span", {
    className: cx(CLASS_INDICATOR, CLASS_INDICATOR + "--" + (indicatorBottom ? 'bottom' : 'top'))
  }, React.createElement("strong", null, percentage), indicatorTotal ? "/100" : "%");
};

var LineProgressBar = function LineProgressBar(props) {
  var percentage = props.percentage,
      indicatorBottom = props.indicatorBottom,
      isAnimatedOnChange = props.isAnimatedOnChange,
      hideIndicator = props.hideIndicator;
  var width = percentage + "%";
  var styleBar = {
    width: width
  };
  return React.createElement("div", {
    className: BASE_CLASS
  }, !hideIndicator && !indicatorBottom && React.createElement(Indicator, props), React.createElement("div", {
    className: CLASS_CONTAINER_BAR
  }, React.createElement("span", {
    className: cx(CLASS_BAR, isAnimatedOnChange && CLASS_BAR_ANIMATED),
    style: styleBar
  })), !hideIndicator && indicatorBottom && React.createElement(Indicator, props));
};

LineProgressBar.displayName = 'LineProgressBar';
export default LineProgressBar;

==> react-atom-progress-bar-1.9.0.tgz: package/lib/LineProgressBar/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomLineProgressBar';
var CLASS_INDICATOR = 'sui-AtomLineProgressBar-indicator';
var CLASS_CONTAINER_BAR = 'sui-AtomLineProgressBar-container';
var CLASS_BAR = 'sui-AtomLineProgressBar-bar';
var CLASS_BAR_ANIMATED = 'sui-AtomLineProgressBar-bar--animated';

var Indicator = function Indicator(props) {
  var indicatorBottom = props.indicatorBottom,
      percentage = props.percentage,
      indicatorTotal = props.indicatorTotal; // eslint-disable-line react/prop-types

  return /*#__PURE__*/React.createElement("span", {
    className: cx(CLASS_INDICATOR, CLASS_INDICATOR + "--" + (indicatorBottom ? 'bottom' : 'top'))
  }, /*#__PURE__*/React.createElement("strong", null, percentage), indicatorTotal ? "/100" : "%");
};

var LineProgressBar = function LineProgressBar(props) {
  var percentage = props.percentage,
      indicatorBottom = props.indicatorBottom,
      isAnimatedOnChange = props.isAnimatedOnChange,
      hideIndicator = props.hideIndicator;
  var width = percentage + "%";
  var styleBar = {
    width: width
  };
  return /*#__PURE__*/React.createElement("div", {
    className: BASE_CLASS
  }, !hideIndicator && !indicatorBottom && /*#__PURE__*/React.createElement(Indicator, props), /*#__PURE__*/React.createElement("div", {
    className: CLASS_CONTAINER_BAR
  }, /*#__PURE__*/React.createElement("span", {
    className: cx(CLASS_BAR, isAnimatedOnChange && CLASS_BAR_ANIMATED),
    style: styleBar
  })), !hideIndicator && indicatorBottom && /*#__PURE__*/React.createElement(Indicator, props));
};

LineProgressBar.displayName = 'LineProgressBar';
export default LineProgressBar;
